import{_ as b}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-DuggdlOu.js";import{A as h}from"./constants-BbL_I6Tk.js";import{e as v,b as y,V as A,l as r,f as B,q as d,n as m,j as p,w as t,p as e,a0 as I,aO as _,B as x,R as a,S as u,k as C,aQ as N,J as S,g as c,ar as T}from"./jwt-decode.esm-B1xmpboS.js";import{u as D}from"./workspaceStore-Co5THJp9.js";import{C as E}from"./index-CzrlPNrx.js";import"./logo-BiWG9_W5.js";import"./Logo-BUKKlA-2.js";import"./userStore-BPzNJRj9.js";import"./runnerData-Do8aW6Nc.js";import"./url-C54LmHmv.js";import"./colorHelpers-DAgQ40oE.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new j().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="b0730329-3df2-4343-9ecd-93d87ec32f89",o._sentryDebugIdIdentifier="sentry-dbid-b0730329-3df2-4343-9ecd-93d87ec32f89")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},H=v({__name:"Error",setup(o){const i=A(),g=S(),f=D(),w=y(()=>f.state.workspace?.name??f.state.workspace?.brandName),n=y(()=>{const{status:l}=i.params;switch(l){case"404":return{status:l,title:r.translate("i18n_page_not_found"),message:r.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:l,title:r.translate("i18n_access_denied"),message:r.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:r.translate("i18n_internal_error"),message:r.translate("i18n_internal_error_message"),showAd:!1}}}),k=()=>{g.push({name:"playerHome"})};return(l,s)=>(c(),B("div",R,[d(e(I),null,{default:t(()=>[a(u(n.value.title),1)]),_:1}),d(e(_),{class:"message"},{default:t(()=>[a(u(n.value.message),1)]),_:1}),n.value.action?(c(),m(e(x),{key:0,type:"link",onClick:k},{default:t(()=>[a(u(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(c(),m(e(E),{key:1,bordered:!1,class:"card"},{default:t(()=>[C("div",V,[d(b,{style:{"margin-bottom":"10px"}}),d(e(_),null,{default:t(()=>[a("This page is part of "+u(w.value?`the ${w.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(f).state.workspace?(c(),m(e(_),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),d(e(N),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}}),j=T(H,[["__scopeId","data-v-522ad0d4"]]);export{j as default};
//# sourceMappingURL=Error-BTKcuF6D.js.map
