import{e as _,J as g,r as y,$ as b,f as m,g as n,n as c,w as s,q as l,p as a,U as w,R as u,S as p,B as v,l as f,aN as R,aU as h,ar as k}from"./jwt-decode.esm-B1xmpboS.js";import{u as x}from"./organizationSwitcher-BeuPkreB.js";import"./router-CA-zRWYJ.js";import"./ts.worker-BXwpTEAV.js";import"./organization-BcsFoOiZ.js";import"./tables-B5MtFR4Z.js";import"./string-CqFhv0os.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="8701ddd4-89b2-4128-996a-14a5bd66ba95",e._sentryDebugIdIdentifier="sentry-dbid-8701ddd4-89b2-4128-996a-14a5bd66ba95")}catch{}})();const D={class:"loading-container"},I=_({__name:"RootRedirector",setup(e){const r=x(),i=g(),o=y(null);async function d(){o.value=null;try{const t=await r.selectDefaultOrganization();t.name==="onboarding"?window.location.href="/onboarding":i.replace(t)}catch(t){o.value=f.translate("i18n_projectsview_loading_error"),console.error("RootRedirector failed:",t)}}return b(d),(t,B)=>(n(),m("div",D,[o.value?(n(),c(a(R),{key:0,vertical:"",align:"center",gap:16},{default:s(()=>[l(a(w),{type:"danger"},{default:s(()=>[u(p(o.value),1)]),_:1}),l(a(v),{type:"primary",onClick:d},{default:s(()=>[u(p(a(f).translate("i18n_projectsview_retry")),1)]),_:1})]),_:1})):(n(),c(a(h),{key:1,size:"large"}))]))}}),T=k(I,[["__scopeId","data-v-c1eea334"]]);export{T as default};
//# sourceMappingURL=RootRedirector-B9Tydrha.js.map
