import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-DLm_5mSp.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-B1xmpboS.js";import{u as d}from"./projectStore-CQauBoCr.js";import"./router-CA-zRWYJ.js";import"./ts.worker-BXwpTEAV.js";import"./fetch-B_mJcL05.js";import"./tables-B5MtFR4Z.js";import"./string-CqFhv0os.js";import"./SaveButton-DQ6L8vJA.js";import"./ExclamationCircleOutlined-Ct-ecd2V.js";import"./CrudView-Dy-6ZjI9.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-CUvscjpd.js";import"./constants-BbL_I6Tk.js";import"./url-C54LmHmv.js";import"./PhDotsThreeVertical.vue-C1kDAnCV.js";import"./index-C_QtHxBt.js";import"./asyncComputed-Ds_-r_-9.js";import"./PhPencil.vue-Cdh59807.js";import"./useCodebaseEvents-kJcGtvup.js";import"./contracts.generated-tMbjRJss.js";import"./index-BDDcUMd0.js";import"./project-6AKu7_Tx.js";import"./organizationSwitcher-BeuPkreB.js";import"./organization-BcsFoOiZ.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="8d0df1cd-7094-4b81-ac5d-b9263eed10a6",o._sentryDebugIdIdentifier="sentry-dbid-8d0df1cd-7094-4b81-ac5d-b9263eed10a6")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=d(),e=new t(r.projectId);return(a,c)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-C5tDlELa.js.map
