import{B as l}from"./BaseLayout-Ds7YygPi.js";import{C as p}from"./ContentLayout-0sEEUMp-.js";import{e as f,V as b,b as i,N as _,Z as g,n as r,g as s,w as d,q as y,j as w}from"./jwt-decode.esm-B1xmpboS.js";import{_ as z}from"./BillingAlert.vue_vue_type_script_setup_true_lang-CsBjwVGD.js";import{u as h}from"./projectsStore-io0ZBTD4.js";import"./router-CA-zRWYJ.js";import"./ts.worker-BXwpTEAV.js";import"./index-BDDcUMd0.js";import"./member-1JafOa_M.js";import"./organization-BcsFoOiZ.js";import"./project-6AKu7_Tx.js";import"./tables-B5MtFR4Z.js";import"./string-CqFhv0os.js";import"./cascaderStore-DHr6ynPY.js";import"./organizationSwitcher-BeuPkreB.js";import"./ant-design-BWj-h800.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="8b864bed-03cb-4a89-a473-49e22836f36b",t._sentryDebugIdIdentifier="sentry-dbid-8b864bed-03cb-4a89-a473-49e22836f36b")}catch{}})();const P=f({__name:"Organization",setup(t){const e=b(),o=h(),n=i(()=>e.params.organizationId);_(n,a=>{a&&o.fetchedState?.organization?.id!==a&&o.fetchState(a)},{immediate:!0});const u=i(()=>o.fetchedState?.organization),m=i(()=>u.value?.billingMetadata);return(a,v)=>{const c=g("RouterView");return s(),r(l,null,{content:d(()=>[y(p,null,{default:d(()=>[m.value?(s(),r(z,{key:0,"billing-metadata":m.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(c,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-DGwWTQ0D.js.map
