import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-DDH7zRXI.js";import{e as d,f as i,q as u,p as n,J as m,V as l,g as f,ar as _}from"./jwt-decode.esm-B1xmpboS.js";import{u as b}from"./workspaceStore-Co5THJp9.js";import"./OTPInput-7m0ch3i9.js";import"./Logo-BUKKlA-2.js";import"./string-CqFhv0os.js";import"./CircularLoading-9tLV8TKO.js";import"./index-BDDcUMd0.js";import"./userStore-BPzNJRj9.js";import"./runnerData-Do8aW6Nc.js";import"./url-C54LmHmv.js";import"./colorHelpers-DAgQ40oE.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6aa9cc04-640b-488d-af87-83c0218d617b",e._sentryDebugIdIdentifier="sentry-dbid-6aa9cc04-640b-488d-af87-83c0218d617b")}catch{}})();const g={class:"runner"},y=d({__name:"Login",setup(e){const o=m(),r=l(),t=b(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(f(),i("div",g,[u(p,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-Ds1qMrse.js.map
