import{N as c}from"./Navbar-BYUST4wx.js";import{e as d,V as u,b as a,l,Z as _,f,g as y,q as p,k as I,ar as b}from"./jwt-decode.esm-B1xmpboS.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-CqpCOX-v.js";import"./LoadingOutlined-CPK33-ov.js";import"./constants-BbL_I6Tk.js";import"./PhCaretDown.vue-fzX0Ei-N.js";import"./PhPencilSimple.vue-CR_RqrEo.js";import"./router-CA-zRWYJ.js";import"./ts.worker-BXwpTEAV.js";import"./organization-BcsFoOiZ.js";import"./tables-B5MtFR4Z.js";import"./string-CqFhv0os.js";import"./keyboard-G_iQxx4R.js";import"./os-B7x4wwFA.js";import"./projectStore-CQauBoCr.js";import"./project-6AKu7_Tx.js";import"./organizationSwitcher-BeuPkreB.js";import"./cascaderStore-DHr6ynPY.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-B5h9SIGt.js";import"./member-1JafOa_M.js";import"./index-D3EKPyfu.js";import"./index-CzrlPNrx.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-CIZDLDan.js";import"./PhNotePencil.vue-BB0GjbiX.js";import"./PhTranslate.vue-Bl8tfebQ.js";import"./PhSignOut.vue-CcVHJxoN.js";import"./index-C_QtHxBt.js";import"./index-jRZIwSs8.js";import"./PhPlus.vue-DI9mFePs.js";import"./omniChatStore-CSk67wDA.js";import"./files-ChuoJJaK.js";import"./contracts.generated-tMbjRJss.js";import"./runnerData-Do8aW6Nc.js";import"./url-C54LmHmv.js";import"./colorHelpers-DAgQ40oE.js";import"./uuid-C6qC7yXk.js";import"./PhCopySimple.vue-DeOdSqEE.js";import"./PhSparkle.vue-B-IUL0VG.js";import"./index-DrEpgaoc.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="30ac8298-727a-4289-86d2-0627910b062d",r._sentryDebugIdIdentifier="sentry-dbid-30ac8298-727a-4289-86d2-0627910b062d")}catch{}})();const g={class:"console-layout"},v={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=_("RouterView");return y(),f("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),I("div",v,[p(e)])])}}}),no=b(w,[["__scopeId","data-v-62f8634d"]]);export{no as default};
//# sourceMappingURL=ConsoleLayout-CYj0QpZd.js.map
