import{_ as r}from"./logo-BiWG9_W5.js";import{L as o}from"./Logo-BUKKlA-2.js";import{e as s,n as d,p as i,g as a}from"./jwt-decode.esm-B1xmpboS.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="10455012-d3e1-49e6-986b-8fb5456e8dbd",e._sentryDebugIdIdentifier="sentry-dbid-10455012-d3e1-49e6-986b-8fb5456e8dbd")}catch{}})();const u=s({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(a(),d(o,{"image-url":i(r),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-DuggdlOu.js.map
